@@ -305,20 +305,32 @@ class AsyncManiac:
             if not isinstance(dataset, list) or len(dataset) == 0:
                 raise RuntimeError("dataset must be a non-empty array")
 
-            converted, inferred_system_prompt = validate_and_convert_dataset(dataset)
+            inferred_system_prompt = dataset[0]["system_prompt"]
+            converted = dataset
+            
+            # converted, inferred_system_prompt = validate_and_convert_dataset(dataset)
             task: Dict[str, Any] = {
                 "system_prompt": inferred_system_prompt,
                 "label": container.get("label"),
             }
             payload = {"task": task, "data": converted}
+
+            print("Payload constructed :)")
+
+            # Debug: Compute and print the exact URL being called
+            # subdomain = "api" if self._outer.baseURLIsCustom else "inference"
+            subdomain = "api"
+            path = "/functions/v1/direct-insert"
+            full_url = f"{self._outer.baseURL.replace('api', subdomain)}{path}"
+
             raw = await self._outer._request_json(
-                "/functions/v1/direct-insert",
+                path,
                 {
                     "method": "POST",
                     "headers": self._outer._headers(),
                     "body": json.dumps(payload),
                 },
-                "api" if self._outer.baseURLIsCustom else "inference",
+                subdomain,
             )
             return {
                 "status": "ok",
